<?php

namespace App\Console\Commands\Zing;

use App\Helpers\Constants;
use App\Models\Crontjob;
use App\Models\Track;
use App\Repositories\TrackRepository;
use Carbon\Carbon;
use Illuminate\Console\Command;

class ZingCrawlerTrackImageCommand extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'zing:get-track-image';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Lấy ảnh đại diện của bài hát từ nguồn zing';

    protected $trackRepository;

    /**
     * Create a new command instance.
     *
     * ZingCrawlerTrackImageCommand constructor.
     * @param TrackRepository $trackRepository
     */
    public function __construct(TrackRepository $trackRepository)
    {
        parent::__construct();
        $this->trackRepository = $trackRepository;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $tracks = $this->trackRepository->getTrackImageEmpty();

        echo "\nTổng số bài hát cần lấy ảnh về: " . count($tracks);

        if (is_array($tracks) && count($tracks) > 0) {
            foreach ($tracks as $key => $track) {
                if ($track['src_thumbnail_medium']) {
                    $file_name = md5($track['id']) . '.png';
                    $file_path = Constants::VMUSICCHART_IMG_TRACKS . $file_name;

                    @copy(Constants::VMUSICCHART_IMG_EMPTY_PNG, $file_path);
                    @file_put_contents($file_path, @file_get_contents($track['src_thumbnail_medium']));

                    $track = Track::find($track['id']);
                    if ($track) {
                        $track->art = Constants::VMUSICCHART_IMG_TRACKS_DB . $file_name;
                        $track->save();
                    }
                }
            }
        }

        echo "\nTải ảnh kết thúc.";

        // Ghi log
        Crontjob::create(['message' => 'ZingCrawlerTrackImageCommand is called at ' . Carbon::now()]);
    }
}
